Index: /trunk/FACT++/src/StateMachineImp.h
===================================================================
--- /trunk/FACT++/src/StateMachineImp.h	(revision 10687)
+++ /trunk/FACT++/src/StateMachineImp.h	(revision 10688)
@@ -72,11 +72,11 @@
     virtual std::string SetCurrentState(int state, const char *txt="", const std::string &cmd="");
 
-    EventImp &AddTransition(int targetstate, const char *name, const char *states, const char *fmt);
-    EventImp &AddTransition(int targetstate, const char *name, int s1=-1, int s2=-1, int s3=-1, int s4=-1, int s5=-1);
-    EventImp &AddTransition(int targetstate, const char *name, const char *fmt, int s1=-1, int s2=-1, int s3=-1, int s4=-1, int s5=-1);
-
-    EventImp &AddConfiguration(const char *name, const char *states, const char *fmt);
-    EventImp &AddConfiguration(const char *name, int s1=-1, int s2=-1, int s3=-1, int s4=-1, int s5=-1);
-    EventImp &AddConfiguration(const char *name, const char *fmt, int s1=-1, int s2=-1, int s3=-1, int s4=-1, int s5=-1);
+    EventImp &AddEvent(int targetstate, const char *name, const char *states, const char *fmt);
+    EventImp &AddEvent(int targetstate, const char *name, int s1=-1, int s2=-1, int s3=-1, int s4=-1, int s5=-1);
+    EventImp &AddEvent(int targetstate, const char *name, const char *fmt, int s1=-1, int s2=-1, int s3=-1, int s4=-1, int s5=-1);
+
+    EventImp &AddEvent(const char *name, const char *states, const char *fmt);
+    EventImp &AddEvent(const char *name, int s1=-1, int s2=-1, int s3=-1, int s4=-1, int s5=-1);
+    EventImp &AddEvent(const char *name, const char *fmt, int s1=-1, int s2=-1, int s3=-1, int s4=-1, int s5=-1);
 
     virtual void AddStateName(const int state, const std::string &name, const std::string &doc="");
Index: /trunk/FACT++/src/dataLogger.cc
===================================================================
--- /trunk/FACT++/src/dataLogger.cc	(revision 10687)
+++ /trunk/FACT++/src/dataLogger.cc	(revision 10688)
@@ -590,39 +590,39 @@
 
                 /*Add the possible transitions for this machine*/
-                AddTransition(kSM_NightlyOpen, fTransStart, kSM_Ready, kSM_BadNightlyConfig)
+                AddEvent(kSM_NightlyOpen, fTransStart, kSM_Ready, kSM_BadNightlyConfig)
                     (boost::bind(&DataLogger::StartPlease, this))
                     ("Start the nightly logging. Nightly file location must be specified already");
 
-                AddTransition(kSM_Ready, fTransStop, kSM_NightlyOpen, kSM_WaitingRun, kSM_Logging)
+                AddEvent(kSM_Ready, fTransStop, kSM_NightlyOpen, kSM_WaitingRun, kSM_Logging)
                     (boost::bind(&DataLogger::GoToReadyPlease, this))
                     ("Stop all data logging, close all files.");
 
-                AddTransition(kSM_Logging, fTransStartRun, kSM_WaitingRun, kSM_BadRunConfig)
+                AddEvent(kSM_Logging, fTransStartRun, kSM_WaitingRun, kSM_BadRunConfig)
                     (boost::bind(&DataLogger::StartRunPlease, this))
                     ("Start the run logging. Run file location must be specified already.");
 
-                AddTransition(kSM_WaitingRun, fTransStopRun, kSM_Logging)
+                AddEvent(kSM_WaitingRun, fTransStopRun, kSM_Logging)
                     (boost::bind(&DataLogger::StopRunPlease, this))
                     ("Wait for a run to be started, open run-files as soon as a run number arrives.");
 
-                AddTransition(kSM_Ready, fTransReset, kSM_Error, kSM_BadNightlyConfig, kSM_BadRunConfig, kSM_Error)
+                AddEvent(kSM_Ready, fTransReset, kSM_Error, kSM_BadNightlyConfig, kSM_BadRunConfig, kSM_Error)
                     (boost::bind(&DataLogger::GoToReadyPlease, this))
                     ("Transition to exit error states. Closes the nightly file if already opened.");
 
-                AddTransition(kSM_WaitingRun, fTransWait, kSM_NightlyOpen)
+                AddEvent(kSM_WaitingRun, fTransWait, kSM_NightlyOpen)
                     (boost::bind(&DataLogger::NightlyToWaitRunPlease, this));
 
                 /*Add the possible configurations for this machine*/
-                AddConfiguration(fConfigDay, "C", kSM_Ready, kSM_BadNightlyConfig)
+                AddEvent(fConfigDay, "C", kSM_Ready, kSM_BadNightlyConfig)
                     (boost::bind(&DataLogger::ConfigureNightlyFileName, this, _1))
                     ("Configure the folder for the nightly files."
                      "|Path[string]:Absolute or relative path name where the nightly files should be stored.");
 
-                AddConfiguration(fConfigRun, "C", kSM_Ready, kSM_BadNightlyConfig, kSM_NightlyOpen, kSM_WaitingRun, kSM_BadRunConfig)
+                AddEvent(fConfigRun, "C", kSM_Ready, kSM_BadNightlyConfig, kSM_NightlyOpen, kSM_WaitingRun, kSM_BadRunConfig)
                     (boost::bind(&DataLogger::ConfigureRunFileName, this, _1))
                     ("Configure the folder for the run files."
                      "|Path[string]:Absolute or relative path name where the run files should be stored.");
 
-                AddConfiguration(fConfigRunNumber, "I", kSM_Ready, kSM_BadNightlyConfig, kSM_NightlyOpen, kSM_WaitingRun, kSM_BadRunConfig)
+                AddEvent(fConfigRunNumber, "I", kSM_Ready, kSM_BadNightlyConfig, kSM_NightlyOpen, kSM_WaitingRun, kSM_BadRunConfig)
                     (boost::bind(&DataLogger::ConfigureRunNumber, this, _1))
                     ("configure the run number. cannot be done in logging state");
@@ -633,5 +633,5 @@
                 //is already done in StateMachineImp.cc
                 //Thus I'll simply add a configuration, which I will treat as the logging command
-                AddConfiguration(fConfigLog, "C", kSM_NightlyOpen, kSM_Logging, kSM_WaitingRun, kSM_BadRunConfig)
+                AddEvent(fConfigLog, "C", kSM_NightlyOpen, kSM_Logging, kSM_WaitingRun, kSM_BadRunConfig)
                     (boost::bind(&DataLogger::LogMessagePlease, this, _1))
                     ("Log a single message to the log-files."
@@ -643,6 +643,6 @@
                 str << " " << kSM_BadRunConfig;
 
-				AddConfiguration(fPrintCommand, str.str().c_str(), "")
-//                AddConfiguration(fPrintCommand, kSM_NightlyOpen, kSM_Logging, kSM_WaitingRun, kSM_BadNightlyConfig, kSM_BadRunConfig)
+				AddEvent(fPrintCommand, str.str().c_str(), "")
+//                AddEvent(fPrintCommand, kSM_NightlyOpen, kSM_Logging, kSM_WaitingRun, kSM_BadNightlyConfig, kSM_BadRunConfig)
                     (boost::bind(&DataLogger::PrintStatePlease, this, _1))
                     ("Print information about the internal status of the data logger.");
@@ -688,19 +688,19 @@
 
                 //provide services control commands
-                AddConfiguration(fDebugOnOff, "B:1", kSM_NightlyOpen, kSM_Logging, kSM_WaitingRun, kSM_Ready)
+                AddEvent(fDebugOnOff, "B:1", kSM_NightlyOpen, kSM_Logging, kSM_WaitingRun, kSM_Ready)
                     (boost::bind(&DataLogger::SetDebugOnOff, this, _1))
                     ("Switch debug mode on off. Debug mode prints ifnormation about every service written to a file."
                      "|Enable[bool]:Enable of disable debuig mode (yes/no).");
 
-                AddConfiguration(fStatsPeriod, "F", kSM_NightlyOpen, kSM_Logging, kSM_WaitingRun, kSM_Ready)
+                AddEvent(fStatsPeriod, "F", kSM_NightlyOpen, kSM_Logging, kSM_WaitingRun, kSM_Ready)
                     (boost::bind(&DataLogger::SetStatsPeriod, this, _1))
                     ("Interval in which the data-logger statitistics service (STATS) is updated."
                      "Interval[s]:Floating point value in seconds.");
 
-                AddConfiguration(fStartStopOpenedFiles, "B:1", kSM_NightlyOpen, kSM_Logging, kSM_WaitingRun, kSM_Ready)
+                AddEvent(fStartStopOpenedFiles, "B:1", kSM_NightlyOpen, kSM_Logging, kSM_WaitingRun, kSM_Ready)
                     (boost::bind(&DataLogger::SetOpenedFilesOnOff ,this, _1))
                     ("Can be used to switch the service off which distributes information about the open files.");
 
-                AddConfiguration(fStartStopNumSubsAndFits, "B:1", kSM_NightlyOpen, kSM_Logging, kSM_WaitingRun, kSM_Ready)
+                AddEvent(fStartStopNumSubsAndFits, "B:1", kSM_NightlyOpen, kSM_Logging, kSM_WaitingRun, kSM_Ready)
                     (boost::bind(&DataLogger::SetNumSubsAndFitsOnOff, this, _1))
                     ("Can be used to switch the service off which distributes information about the number of subscriptions and open files.");
Index: /trunk/FACT++/src/dclient5.cc
===================================================================
--- /trunk/FACT++/src/dclient5.cc	(revision 10687)
+++ /trunk/FACT++/src/dclient5.cc	(revision 10688)
@@ -255,22 +255,22 @@
         AddStateName(kSM_Stopping,      "Stopping");
 
-        AddTransition(kSM_Running,   "START", kSM_Connected).
+        AddEvent(kSM_Running,   "START", kSM_Connected).
             AssignFunction(boost::bind(&StateMachineFAD::Start, this, _1, 5));
-        AddTransition(kSM_Connected, "STOP",  kSM_Running);
-
-        AddConfiguration("TIME", kSM_Running);
-        AddConfiguration("LED",  kSM_Connected);
-
-        T::AddConfiguration("TESTI",    "I");
-        T::AddConfiguration("TESTI2",   "I:2");
-        T::AddConfiguration("TESTIF",   "I:2;F:2");
-        T::AddConfiguration("TESTIC",   "I:2;C");
-
-        T::AddConfiguration("CMD", "C").
+        AddEvent(kSM_Connected, "STOP",  kSM_Running);
+
+        AddEvent("TIME", kSM_Running);
+        AddEvent("LED",  kSM_Connected);
+
+        T::AddEvent("TESTI",    "I");
+        T::AddEvent("TESTI2",   "I:2");
+        T::AddEvent("TESTIF",   "I:2;F:2");
+        T::AddEvent("TESTIC",   "I:2;C");
+
+        T::AddEvent("CMD", "C").
             AssignFunction(boost::bind(&StateMachineFAD::Command, this, _1));
 
-        AddTransition(kSM_Reconnect, "RECONNECT");
-
-        AddTransition(kSM_SetUrl, "SETURL", "C");
+        AddEvent(kSM_Reconnect, "RECONNECT");
+
+        AddEvent(kSM_SetUrl, "SETURL", "C");
     }
 
Index: /trunk/FACT++/src/ftmctrl.cc
===================================================================
--- /trunk/FACT++/src/ftmctrl.cc	(revision 10687)
+++ /trunk/FACT++/src/ftmctrl.cc	(revision 10688)
@@ -1401,26 +1401,26 @@
 
         // FTM Commands
-        AddConfiguration("TOGGLE_LED", kStateIdle)
+        AddEvent("TOGGLE_LED", kStateIdle)
             (Wrapper(boost::bind(&ConnectionFTM::CmdToggleLed, &fFTM)))
             ("toggle led");
 
-        AddConfiguration("PING", kStateIdle)
+        AddEvent("PING", kStateIdle)
             (Wrapper(boost::bind(&ConnectionFTM::CmdPing, &fFTM)))
             ("send ping");
 
-        AddConfiguration("REQUEST_DYNAMIC_DATA", kStateIdle)
+        AddEvent("REQUEST_DYNAMIC_DATA", kStateIdle)
             (Wrapper(boost::bind(&ConnectionFTM::CmdReqDynDat, &fFTM)))
             ("request transmission of dynamic data block");
 
-        AddConfiguration("REQUEST_STATIC_DATA", kStateIdle)
+        AddEvent("REQUEST_STATIC_DATA", kStateIdle)
             (Wrapper(boost::bind(&ConnectionFTM::CmdReqStatDat, &fFTM)))
             ("request transmission of static data from FTM to memory");
 
-        AddConfiguration("GET_REGISTER", "I", kStateIdle)
+        AddEvent("GET_REGISTER", "I", kStateIdle)
             (boost::bind(&StateMachineFTM::GetRegister, this, _1))
             ("read register from address addr"
             "|addr[short]:Address of register");
 
-        AddConfiguration("SET_REGISTER", "I:2", kStateIdle)
+        AddEvent("SET_REGISTER", "I:2", kStateIdle)
             (boost::bind(&StateMachineFTM::SetRegister, this, _1))
             ("set register to value"
@@ -1428,22 +1428,22 @@
             "|val[short]:Value to be set");
 
-        AddConfiguration("START_RUN", kStateIdle)
+        AddEvent("START_RUN", kStateIdle)
             (Wrapper(boost::bind(&ConnectionFTM::CmdStartRun, &fFTM)))
             ("start a run (start distributing triggers)");
 
-        AddConfiguration("STOP_RUN", kStateTakingData)
+        AddEvent("STOP_RUN", kStateTakingData)
             (Wrapper(boost::bind(&ConnectionFTM::CmdStopRun, &fFTM)))
             ("stop a run (stop distributing triggers)");
 
-        AddConfiguration("TAKE_N_EVENTS", "I", kStateIdle)
+        AddEvent("TAKE_N_EVENTS", "I", kStateIdle)
             (boost::bind(&StateMachineFTM::TakeNevents, this, _1))
             ("take n events (distribute n triggers)|number[int]:Number of events to be taken");
 
-        AddConfiguration("DISABLE_REPORTS", "B", kStateIdle)
+        AddEvent("DISABLE_REPORTS", "B", kStateIdle)
             (boost::bind(&StateMachineFTM::DisableReports, this, _1))
             ("disable sending rate reports"
              "|status[bool]:disable or enable that the FTM sends rate reports (yes/no)");
 
-        AddConfiguration("SET_THRESHOLD", "I:2", kStateIdle)
+        AddEvent("SET_THRESHOLD", "I:2", kStateIdle)
             (boost::bind(&StateMachineFTM::SetThreshold, this, _1))
             ("Set the comparator threshold"
@@ -1451,10 +1451,10 @@
              "|Threshold[counts]:Threshold to be set in binary counts");
 
-        AddConfiguration("SET_PRESCALING", "I:1", kStateIdle)
+        AddEvent("SET_PRESCALING", "I:1", kStateIdle)
             (boost::bind(&StateMachineFTM::SetPrescaling, this, _1))
             (""
              "|[]:");
 
-        AddConfiguration("ENABLE_FTU", "I:1;B:1", kStateIdle)
+        AddEvent("ENABLE_FTU", "I:1;B:1", kStateIdle)
             (boost::bind(&StateMachineFTM::EnableFTU, this, _1))
             ("Enable or disable FTU"
@@ -1462,30 +1462,30 @@
              "|Enable[bool]:Whether FTU should be enabled or disabled (yes/no)");
 
-        AddConfiguration("TOGGLE_FTU", "I:1", kStateIdle)
+        AddEvent("TOGGLE_FTU", "I:1", kStateIdle)
             (boost::bind(&StateMachineFTM::ToggleFTU, this, _1))
             ("Toggle status of FTU (this is mainly meant to be used in the GUI)"
              "|Board[idx]:Index of the board (0-39)");
 
-        AddConfiguration("SET_TRIGGER_INTERVAL", "I:1", kStateIdle)
+        AddEvent("SET_TRIGGER_INTERVAL", "I:1", kStateIdle)
             (boost::bind(&StateMachineFTM::SetTriggerInterval, this, _1))
             ("Sets the trigger interval which is the distance between two consecutive artificial triggers."
              "|interval[int]:The applied trigger interval is: interval*4ns+8ns");
 
-        AddConfiguration("SET_TRIGGER_DELAY", "I:1", kStateIdle)
+        AddEvent("SET_TRIGGER_DELAY", "I:1", kStateIdle)
             (boost::bind(&StateMachineFTM::SetTriggerDelay, this, _1))
             (""
              "|delay[int]:The applied trigger delay is: delay*4ns+8ns");
 
-        AddConfiguration("SET_TIME_MARKER_DELAY", "I:1", kStateIdle)
+        AddEvent("SET_TIME_MARKER_DELAY", "I:1", kStateIdle)
             (boost::bind(&StateMachineFTM::SetTimeMarkerDelay, this, _1))
             (""
             "|delay[int]:The applied time marker delay is: delay*4ns+8ns");
 
-        AddConfiguration("SET_DEAD_TIME", "I:1", kStateIdle)
+        AddEvent("SET_DEAD_TIME", "I:1", kStateIdle)
             (boost::bind(&StateMachineFTM::SetDeadTime, this, _1))
             (""
             "|dead_time[int]:The applied dead time is: dead_time*4ns+8ns");
 
-        AddConfiguration("ENABLE_TRIGGER", "B:1", kStateIdle)
+        AddEvent("ENABLE_TRIGGER", "B:1", kStateIdle)
             (boost::bind(&StateMachineFTM::Enable, this, _1, FTM::StaticData::kTrigger))
             ("Switch on the physics trigger"
@@ -1493,5 +1493,5 @@
 
         // FIXME: Switch on/off depending on sequence
-        AddConfiguration("ENABLE_EXT1", "B:1", kStateIdle)
+        AddEvent("ENABLE_EXT1", "B:1", kStateIdle)
             (boost::bind(&StateMachineFTM::Enable, this, _1, FTM::StaticData::kExt1))
             ("Switch on the triggers through the first external line"
@@ -1499,15 +1499,15 @@
 
         // FIXME: Switch on/off depending on sequence
-        AddConfiguration("ENABLE_EXT2", "B:1", kStateIdle)
+        AddEvent("ENABLE_EXT2", "B:1", kStateIdle)
             (boost::bind(&StateMachineFTM::Enable, this, _1, FTM::StaticData::kExt2))
             ("Switch on the triggers through the second external line"
              "|Enable[bool]:Enable ext2 trigger (yes/no)");
 
-        AddConfiguration("ENABLE_VETO", "B:1", kStateIdle)
+        AddEvent("ENABLE_VETO", "B:1", kStateIdle)
             (boost::bind(&StateMachineFTM::Enable, this, _1, FTM::StaticData::kVeto))
             ("Enable veto line"
              "|Enable[bool]:Enable veto (yes/no)");
 
-        AddConfiguration("SET_TRIGGER_SEQUENCE", "C:3", kStateIdle)
+        AddEvent("SET_TRIGGER_SEQUENCE", "C:3", kStateIdle)
             (boost::bind(&StateMachineFTM::SetTriggerSeq, this, _1))
             ("Setup the sequence of artificial triggers produced by the FTM"
@@ -1516,19 +1516,19 @@
              "|LPext[int]:number of triggers of the external light pulser");
 
-        AddConfiguration("SET_TRIGGER_COINCIDENCE", "S:1", kStateIdle)
+        AddEvent("SET_TRIGGER_COINCIDENCE", "S:1", kStateIdle)
             (boost::bind(&StateMachineFTM::SetTriggerCoincidence, this, _1))
             ("Setup the coincidence condition for physcis triggers"
              "|N[int]:Number of requirered coincident triggers from sum-patches (1-40)");
 
-        AddConfiguration("SET_TRIGGER_WINDOW", "S:1", kStateIdle)
+        AddEvent("SET_TRIGGER_WINDOW", "S:1", kStateIdle)
             (boost::bind(&StateMachineFTM::SetTriggerWindow, this, _1))
             ("");
 
-        AddConfiguration("SET_CALIBRATION_COINCIDENCE", "S:1", kStateIdle)
+        AddEvent("SET_CALIBRATION_COINCIDENCE", "S:1", kStateIdle)
             (boost::bind(&StateMachineFTM::SetCalibCoincidence, this, _1))
             ("Setup the coincidence condition for artificial (calibration) triggers"
              "|N[int]:Number of requirered coincident triggers from sum-patches (1-40)");
 
-        AddConfiguration("SET_CALIBRATION_WINDOW", "S:1", kStateIdle)
+        AddEvent("SET_CALIBRATION_WINDOW", "S:1", kStateIdle)
             (boost::bind(&StateMachineFTM::SetCalibWindow, this, _1))
             ("");
@@ -1536,10 +1536,10 @@
 
         // Load/save static data block
-        T::AddConfiguration("SAVE", "C", kStateIdle)
+        T::AddEvent("SAVE", "C", kStateIdle)
             (boost::bind(&StateMachineFTM::SaveStaticData, this, _1))
             ("Saves the static data (FTM configuration) from memory to a file"
              "|filename[string]:Filename (can include a path), .bin is automatically added");
 
-        T::AddConfiguration("LOAD", "C", kStateIdle)
+        T::AddEvent("LOAD", "C", kStateIdle)
             (boost::bind(&StateMachineFTM::LoadStaticData, this, _1))
             ("Loads the static data (FTM configuration) from a file into memory and sends it to the FTM"
@@ -1549,15 +1549,15 @@
 
         // Verbosity commands
-        T::AddConfiguration("SET_VERBOSE", "B")
+        T::AddEvent("SET_VERBOSE", "B")
             (boost::bind(&StateMachineFTM::SetVerbosity, this, _1))
             ("set verbosity state"
              "|verbosity[bool]:disable or enable verbosity for received data (yes/no), except dynamic data");
 
-        T::AddConfiguration("SET_HEX_OUTPUT", "B")
+        T::AddEvent("SET_HEX_OUTPUT", "B")
             (boost::bind(&StateMachineFTM::SetHexOutput, this, _1))
             ("enable or disable hex output for received data"
              "|hexout[bool]:disable or enable hex output for received data (yes/no)");
 
-        T::AddConfiguration("SET_DYNAMIC_OUTPUT", "B")
+        T::AddEvent("SET_DYNAMIC_OUTPUT", "B")
             (boost::bind(&StateMachineFTM::SetDynamicOut, this, _1))
             ("enable or disable output for received dynamic data (data is still broadcasted via Dim)"
@@ -1566,9 +1566,9 @@
 
         // Conenction commands
-        AddConfiguration("DISCONNECT", kStateConnected, kStateIdle)
+        AddEvent("DISCONNECT", kStateConnected, kStateIdle)
             (boost::bind(&StateMachineFTM::Disconnect, this))
             ("disconnect from ethernet");
 
-        AddConfiguration("RECONNECT", "O", kStateDisconnected, kStateConnected, kStateIdle)
+        AddEvent("RECONNECT", "O", kStateDisconnected, kStateConnected, kStateIdle)
             (boost::bind(&StateMachineFTM::Reconnect, this, _1))
             ("(Re)connect ethernet connection to FTM, a new address can be given"
@@ -1576,5 +1576,5 @@
 
         // Other
-        AddTransition(kCmdTest, "TEST", "O")
+        AddEvent(kCmdTest, "TEST", "O")
             (boost::bind(&StateMachineFTM::Test, this, _1))
             ("Just for test purpose, do not use");
Index: /trunk/FACT++/src/scheduler.cc
===================================================================
--- /trunk/FACT++/src/scheduler.cc	(revision 10687)
+++ /trunk/FACT++/src/scheduler.cc	(revision 10688)
@@ -638,6 +638,6 @@
         //AddStateName(kSM_Comitting,   "Comitting");
 
-        AddTransition(kSM_Scheduling, "SCHEDULE", T::kSM_Ready);
-        //AddTransition(kSM_Comitting,  "COMMIT",   T::kSM_Ready);
+        AddEvent(kSM_Scheduling, "SCHEDULE", T::kSM_Ready);
+        //AddEvent(kSM_Comitting,  "COMMIT",   T::kSM_Ready);
 
         T::PrintListOfEvents();

Index: /trunk/FACT++/src/StateMachineImp.cc
===================================================================
--- /trunk/FACT++/src/StateMachineImp.cc	(revision 10687)
+++ /trunk/FACT++/src/StateMachineImp.cc	(revision 10688)
@@ -109,5 +109,5 @@
 //! Subsequent, i.e. derived classes should setup all allowed state
 //! transitions as well as all allowed configuration event by
 //! AddTransition, AddConfiguration and AddStateName.
 //!
 //! @param out
@@ -492,5 +492,5 @@
 //!    greater or equal zero. A negative target state is used to flag
 //!    commands which do not initiate a state transition. If this is
 //!    desired use AddConfiguration instead.
 //!
 //! @param name
@@ -523,5 +523,5 @@
 //!    greater or equal zero. A negative target state is used to flag
 //!    commands which do not initiate a state transition. If this is
 //!    desired use AddConfiguration instead.
 //!
 //! @param name
@@ -540,5 +540,5 @@
 //!    received commands is properly extracted. No check is done.
 //
-EventImp &StateMachineImp::AddTransition(int targetstate, const char *name, const char *states, const char *fmt)
+EventImp &StateMachineImp::AddEvent(int targetstate, const char *name, const char *states, const char *fmt)
 {
     EventImp *evt = CreateEvent(targetstate, name, fmt);
@@ -564,5 +564,5 @@
 //!    greater or equal zero. A negative target state is used to flag
 //!    commands which do not initiate a state transition. If this is
 //!    desired use AddConfiguration instead.
 //!
 //! @param name
@@ -575,9 +575,9 @@
 //!    by this command.
 //
-EventImp &StateMachineImp::AddTransition(int targetstate, const char *name, int s1, int s2, int s3, int s4, int s5)
+EventImp &StateMachineImp::AddEvent(int targetstate, const char *name, int s1, int s2, int s3, int s4, int s5)
 {
     ostringstream str;
     str << s1 << ' '  << s2 << ' ' << s3 << ' ' << s4 << ' ' << s5;
-    return AddTransition(targetstate, name, str.str().c_str(), "");
+    return AddEvent(targetstate, name, str.str().c_str(), "");
 }
 
@@ -592,5 +592,5 @@
 //!    greater or equal zero. A negative target state is used to flag
 //!    commands which do not initiate a state transition. If this is
 //!    desired use AddConfiguration instead.
 //!
 //! @param name
@@ -609,16 +609,16 @@
 //!    by this command.
 //
-EventImp &StateMachineImp::AddTransition(int targetstate, const char *name, const char *fmt, int s1, int s2, int s3, int s4, int s5)
+EventImp &StateMachineImp::AddEvent(int targetstate, const char *name, const char *fmt, int s1, int s2, int s3, int s4, int s5)
 {
     ostringstream str;
     str << s1 << ' '  << s2 << ' ' << s3 << ' ' << s4 << ' ' << s5;
-    return AddTransition(targetstate, name, str.str().c_str(), fmt);
-}
-
-// --------------------------------------------------------------------------
-//
-//! This function calls AddTransition with a target-state of -1 which means
+    return AddEvent(targetstate, name, str.str().c_str(), fmt);
+}
+
+// --------------------------------------------------------------------------
+//
+//! This function calls AddEvent with a target-state of -1 which means
 //! that the command will not change the state at all. This shell be used
 //! for configuration commands. As well as in AddTransition the states in
 //! which such a configuration command is accepted can be given.
 //!
@@ -638,14 +638,14 @@
 //!    received commands is properly extracted. No check is done.
 //!
-EventImp &StateMachineImp::AddConfiguration(const char *name, const char *states, const char *fmt)
-{
-    return AddTransition(-1, name, states, fmt);
-}
-
-// --------------------------------------------------------------------------
-//
-//! This function calls AddTransition with a target-state of -1 which means
+EventImp &StateMachineImp::AddEvent(const char *name, const char *states, const char *fmt)
+{
+    return AddEvent(-1, name, states, fmt);
+}
+
+// --------------------------------------------------------------------------
+//
+//! This function calls AddEvent with a target-state of -1 which means
 //! that the command will not change the state at all. This shell be used
 //! for configuration commands. As well as in AddTransition the states in
 //! which such a configuration command is accepted can be given.
 //!
@@ -659,14 +659,14 @@
 //!    by this command.
 //
-EventImp &StateMachineImp::AddConfiguration(const char *name, int s1, int s2, int s3, int s4, int s5)
-{
-    return AddTransition(-1, name, s1, s2, s3, s4, s5);
-}
-
-// --------------------------------------------------------------------------
-//
-//! This function calls AddTransition with a target-state of -1 which means
+EventImp &StateMachineImp::AddEvent(const char *name, int s1, int s2, int s3, int s4, int s5)
+{
+    return AddEvent(-1, name, s1, s2, s3, s4, s5);
+}
+
+// --------------------------------------------------------------------------
+//
+//! This function calls AddEvent with a target-state of -1 which means
 //! that the command will not change the state at all. This shell be used
 //! for configuration commands. As well as in AddTransition the states in
 //! which such a configuration command is accepted can be given.
 //!
@@ -686,7 +686,7 @@
 //!    by this command.
 //
-EventImp &StateMachineImp::AddConfiguration(const char *name, const char *fmt, int s1, int s2, int s3, int s4, int s5)
-{
-    return AddTransition(-1, name, fmt, s1, s2, s3, s4, s5);
+EventImp &StateMachineImp::AddEvent(const char *name, const char *fmt, int s1, int s2, int s3, int s4, int s5)
+{
+    return AddEvent(-1, name, fmt, s1, s2, s3, s4, s5);
 }
 
@@ -109,5 +109,5 @@
 //! Subsequent, i.e. derived classes should setup all allowed state
 //! transitions as well as all allowed configuration event by
-//! AddTransition, AddConfiguration and AddStateName.
+//! AddEvent and AddStateName.
 //!
 //! @param out
@@ -492,5 +492,5 @@
 //!    greater or equal zero. A negative target state is used to flag
 //!    commands which do not initiate a state transition. If this is
-//!    desired use AddConfiguration instead.
+//!    desired use AddEvent instead.
 //!
 //! @param name
@@ -523,5 +523,5 @@
 //!    greater or equal zero. A negative target state is used to flag
 //!    commands which do not initiate a state transition. If this is
-//!    desired use AddConfiguration instead.
+//!    desired use AddEvent instead.
 //!
 //! @param name
@@ -564,5 +564,5 @@
 //!    greater or equal zero. A negative target state is used to flag
 //!    commands which do not initiate a state transition. If this is
-//!    desired use AddConfiguration instead.
+//!    desired use AddEvent instead.
 //!
 //! @param name
@@ -592,5 +592,5 @@
 //!    greater or equal zero. A negative target state is used to flag
 //!    commands which do not initiate a state transition. If this is
-//!    desired use AddConfiguration instead.
+//!    desired use AddEvent instead.
 //!
 //! @param name
@@ -609,16 +609,16 @@
 //! that the command will not change the state at all. This shell be used
-//! for configuration commands. As well as in AddTransition the states in
+//! for configuration commands. As well as in AddEvent the states in
 //! which such a configuration command is accepted can be given.
 //!
@@ -638,14 +638,14 @@
 //! that the command will not change the state at all. This shell be used
-//! for configuration commands. As well as in AddTransition the states in
+//! for configuration commands. As well as in AddEvent the states in
 //! which such a configuration command is accepted can be given.
 //!
@@ -659,14 +659,14 @@
 //! that the command will not change the state at all. This shell be used
-//! for configuration commands. As well as in AddTransition the states in
+//! for configuration commands. As well as in AddEvent the states in
 //! which such a configuration command is accepted can be given.
 //!